<?php

namespace Drupal\pki_ra\Processors;

use Drupal\Component\Utility\UrlHelper;

class PKIRACertificationAuthority {
  const CERTIFICATES = 'certificates';

  protected $url;
  protected $status;
  protected $headers;
  protected $response;

  /**
   * @todo Verify that the CA is a trusted host using Symfony\Component\HttpFoundation\Request.
   */
  public function __construct($url) {
    if (!UrlHelper::isValid($url, TRUE)) {
      throw new \Exception('The certificate authority (CA) URL was not entered on the PKI Registration Authority settings page.');
    }
    $this->url = $url;
  }

  public function signCertificate($csr, $profile) {
    $target = $this->url . '/' . self::CERTIFICATES;

    try {
      $request = \Drupal::httpClient()->post($target, ['json' => [
        'csr' => $csr,
        'profile' => $profile,
      ]]);
    }
    catch (Exception $e) {
      watchdog_exception('pki_ra', $e->getMessage());
    }

    $this->status = $request->getStatusCode();
    $this->headers = $request->getHeaders();
    $this->response = json_decode((string) $request->getBody(), TRUE);

    return $this;
  }

  public function getCertificateSigningResponse() {
    return $this->response;
  }

  public function getCertificateSigningHeaders() {
    return $this->headers;
  }

  public function getCertificateSigningStatus() {
    return $this->status;
  }
}
